pub struct WeaponStats {
pub min_damage: f64,
pub max_damage: f64,
pub speed_ms: u32,
pub normalized_speed_s: f64,
pub item_class: i32,
pub subclass: i32,
pub inventory_type: i32,
}Expand description
Per-weapon-slot stats; zeroed means no weapon, so callers must guard against speed_ms == 0.
Fields
min_damage: f64max_damage: f64speed_ms: u32normalized_speed_s: f64item_class: i32subclass: i32inventory_type: i32Trait Implementations
Sourceimpl Clone for WeaponStats
impl Clone for WeaponStats
Sourcefn clone(&self) -> WeaponStats
fn clone(&self) -> WeaponStats
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WeaponStats
impl Debug for WeaponStats
Sourceimpl Default for WeaponStats
impl Default for WeaponStats
Sourcefn default() -> WeaponStats
fn default() -> WeaponStats
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for WeaponStats
impl<'de> Deserialize<'de> for WeaponStats
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<WeaponStats> for JsValuewhere
WeaponStats: Serialize,
impl From<WeaponStats> for JsValuewhere
WeaponStats: Serialize,
Sourcefn from(value: WeaponStats) -> Self
fn from(value: WeaponStats) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for WeaponStatswhere
Self: DeserializeOwned,
impl FromWasmAbi for WeaponStatswhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for &WeaponStatswhere
WeaponStats: Serialize,
impl IntoWasmAbi for &WeaponStatswhere
WeaponStats: Serialize,
Sourceimpl IntoWasmAbi for WeaponStatswhere
WeaponStats: Serialize,
impl IntoWasmAbi for WeaponStatswhere
WeaponStats: Serialize,
Sourceimpl OptionFromWasmAbi for WeaponStatswhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for WeaponStatswhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for WeaponStatswhere
WeaponStats: Serialize,
impl OptionIntoWasmAbi for WeaponStatswhere
WeaponStats: Serialize,
Sourceimpl RefFromWasmAbi for WeaponStatswhere
Self: DeserializeOwned,
impl RefFromWasmAbi for WeaponStatswhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<WeaponStats>
type Anchor = SelfOwner<WeaponStats>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for WeaponStats
impl Serialize for WeaponStats
Sourceimpl Tsify for WeaponStats
impl Tsify for WeaponStats
const DECL: &'static str = "/**\n * Per-weapon-slot stats; zeroed means no weapon, so callers must guard against `speed_ms == 0`.\n */\nexport interface WeaponStats {\n min_damage: number;\n max_damage: number;\n speed_ms: number;\n normalized_speed_s: number;\n item_class: number;\n subclass: number;\n inventory_type: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for WeaponStatswhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for WeaponStatswhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for WeaponStatswhere
WeaponStats: Serialize,
impl VectorIntoWasmAbi for WeaponStatswhere
WeaponStats: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribe for WeaponStats
impl WasmDescribe for WeaponStats
Sourceimpl WasmDescribeVector for WeaponStats
impl WasmDescribeVector for WeaponStats
impl Copy for WeaponStats